@@ -106,7 +106,7 @@ sub query {
   # Blocking
   unless ($cb) {
     $self->_notifications;
-    return $self->results_class->new(sth => $sth);
+    return $self->results_class->new(db => $self, sth => $sth);
   }
 
   # Non-blocking
@@ -172,7 +172,7 @@ sub _watch {
       my $result = do { local $dbh->{RaiseError} = 0; $dbh->pg_result };
       my $err = defined $result ? undef : $dbh->errstr;
 
-      $self->$cb($err, $self->results_class->new(sth => $sth));
+      $self->$cb($err, $self->results_class->new(db => $self, sth => $sth));
       $self->_unwatch unless $self->{waiting} || $self->is_listening;
     }
   )->watch($self->{handle}, 1, 0);
@@ -308,7 +308,7 @@ L<SQL::Abstract>.
   my $promise = $db->delete_p($table, \%where, \%options);
 
 Same as L</"delete">, but performs all operations non-blocking and returns a
-L<Mojo::Promise> object to be used as a promise instead of accepting a callback.
+L<Mojo::Promise> object instead of accepting a callback.
 
   $db->delete_p('some_table')->then(sub {
     my $results = shift;
@@ -369,7 +369,7 @@ L<SQL::Abstract>.
   my $promise = $db->insert_p($table, \@values || \%fieldvals, \%options);
 
 Same as L</"insert">, but performs all operations non-blocking and returns a
-L<Mojo::Promise> object to be used as a promise instead of accepting a callback.
+L<Mojo::Promise> object instead of accepting a callback.
 
   $db->insert_p(some_table => {foo => 'bar'})->then(sub {
     my $results = shift;
@@ -451,7 +451,7 @@ used to bind specific L<DBD::Pg> data types to placeholders.
   my $promise = $db->query_p('select * from foo');
 
 Same as L</"query">, but performs all operations non-blocking and returns a
-L<Mojo::Promise> object to be used as a promise instead of accepting a callback.
+L<Mojo::Promise> object instead of accepting a callback.
 
   $db->query_p('insert into foo values (?, ?, ?)' => @values)->then(sub {
     my $results = shift;
@@ -463,7 +463,7 @@ L<Mojo::Promise> object to be used as a promise instead of accepting a callback.
 
 =head2 select
 
-  my $results = $db->select($source, $fields, $where, $order);
+  my $results = $db->select($source, $fields, $where, \%options);
 
 Generate a C<SELECT> statement with L<Mojo::Pg/"abstract"> (usually an
 L<SQL::Abstract> object) and execute it with L</"query">. You can also append a
@@ -488,17 +488,26 @@ L<SQL::Abstract>.
   $db->select('some_table', undef, {foo => 'bar'});
 
   # "select * from some_table where foo = 'bar' order by id desc"
-  $db->select('some_table', undef, {foo => 'bar'}, {-desc => 'id'});
+  $db->select('some_table', '*', {foo => 'bar'}, {order_by => {-desc => 'id'}});
+
+  # "select * from some_table limit 10 offset 20"
+  $db->select('some_table', undef, undef, {limit => 10, offset => 20});
 
   # "select * from some_table where foo like '%test%'"
   $db->select('some_table', undef, {foo => {-like => '%test%'}});
 
+  # "select * from some_table where foo = 23 group by foo, bar"
+  $db->select('some_table', '*', {foo => 23}, {group_by => \'foo, bar'});
+
+  # "select * from some_table where id = 1 for update skip locked"
+  $db->select('some_table', '*', {id => 1}, {for => \'update skip locked'});
+
 =head2 select_p
 
-  my $promise = $db->select_p($source, $fields, $where, $order);
+  my $promise = $db->select_p($source, $fields, $where, \%options);
 
 Same as L</"select">, but performs all operations non-blocking and returns a
-L<Mojo::Promise> object to be used as a promise instead of accepting a callback.
+L<Mojo::Promise> object instead of accepting a callback.
 
   $db->select_p(some_table => ['foo'] => {bar => 'yada'})->then(sub {
     my $results = shift;
@@ -559,7 +568,7 @@ L<SQL::Abstract>.
   my $promise = $db->update_p($table, \%fieldvals, \%where, \%options);
 
 Same as L</"update">, but performs all operations non-blocking and returns a
-L<Mojo::Promise> object to be used as a promise instead of accepting a
+L<Mojo::Promise> object instead of accepting a
 callback.
 
   $db->update_p(some_table => {foo => 'baz'} => {foo => 'bar'})->then(sub {
